from setuptools import setup

setup(name='dsnd_probabilities_1',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['dsnd_probabilities_1'],
      author='Beatriz Farias',
      author_email = 'beatrizfarias.engcomp@gmail.com',
      zip_safe=False)
